<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://brewpixel.com
 * @since      1.0.0
 *
 * @package    BrewPixel_Reviews
 * @subpackage BrewPixel_Reviews/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    BrewPixel_Reviews
 * @subpackage BrewPixel_Reviews/admin
 * @author     Martin Goldie <martin@brewpixel.com>
 */
class BrewPixel_Reviews_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $brewpixel_reviews    The ID of this plugin.
	 */
	private $brewpixel_reviews;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $brewpixel_reviews       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $brewpixel_reviews, $version ) {

		$this->brewpixel_reviews = $brewpixel_reviews;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in BrewPixel_Reviews_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The BrewPixel_Reviews_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->brewpixel_reviews, plugin_dir_url( __FILE__ ) . 'css/brewpixel-reviews-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in BrewPixel_Reviews_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The BrewPixel_Reviews_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->brewpixel_reviews, plugin_dir_url( __FILE__ ) . 'js/brewpixel-reviews-admin.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * Add custom post type.
	 *
	 * @since    1.0.0
	 */
	public function bp_add_custom_post_types() {

		/**
		 * Add custom post type.
		 */
		if( class_exists( '\BrewPixel\BrewPress\BrewPress' ) ) {

			foreach (
				glob( realpath( __DIR__ . DIRECTORY_SEPARATOR ) . '/post-types/*.php' ) as $filename
			) {
				include_once $filename;
			}

			global $post;
			if( ! is_object($post) ) {
				$postdate = '';
			} else {
				$postdate = $post->post_date;
			}
			$bp_testimonials_admin = new \BrewPixel\BrewPress\CustomPostType\CreateCustomPostType(
				// Type.
				'bp-testimonials',
				// Labels.
				[
					'name'   => _x( 'Testimonials', 'Post type general name (usually plural)', 'brewpixel-bespoke' ),
					// 'name' === 'plural_name' within BrewPress plugin
					'plural_name'   => _x( 'Testimonials', 'Post type general name (usually plural)', 'brewpixel-bespoke' ),
					'singular_name' => _x( 'Testimonial', 'Post type singular name', 'brewpixel-bespoke' ),
					'menu_name'             => _x( 'Testimonials', 'Admin Menu text', 'brewpixel-bespoke' ),
					'name_admin_bar'        => _x( 'Testimonial', 'Add New on Toolbar', 'brewpixel-bespoke' ),
					'add_new'               => __( 'Add New', 'brewpixel-bespoke' ),
					'add_new_item'          => __( 'Add New Testimonial', 'brewpixel-bespoke' ),
					'new_item'              => __( 'New Testimonial', 'brewpixel-bespoke' ),
					'edit_item'             => __( 'Edit Testimonial', 'brewpixel-bespoke' ),
					'all_items'             => __( 'All Testimonials', 'brewpixel-bespoke' ),
					'search_items'          => __( 'Search Testimonials', 'brewpixel-bespoke' ),
					'parent_item_colon'     => __( 'Parent Testimonial:', 'brewpixel-bespoke' ),
					'not_found'             => __( 'No matching testimonials found.', 'brewpixel-bespoke' ),
					'not_found_in_trash'    => __( 'No testimonials found in Trash.', 'brewpixel-bespoke' ),
					'featured_image'        => _x( 'Testimonial Image', 'Overrides the “Featured Image” phrase for this post type. Added in 4.3', 'brewpixel-bespoke' ),
					'set_featured_image'    => _x( 'Set testimonial image', 'Overrides the “Set featured image” phrase for this post type. Added in 4.3', 'brewpixel-bespoke' ),
					'remove_featured_image' => _x( 'Remove testimonial image', 'Overrides the “Remove featured image” phrase for this post type. Added in 4.3', 'brewpixel-bespoke' ),
					'use_featured_image'    => _x( 'Use as testimonial image', 'Overrides the “Use as featured image” phrase for this post type. Added in 4.3', 'brewpixel-bespoke' ),
					'archives'              => _x( 'Testimonial archives', 'The post type archive label used in nav menus. Default “Post Archives”. Added in 4.4', 'brewpixel-bespoke' ),
					'insert_into_item'      => _x( 'Insert into testimonial', 'Overrides the “Insert into post”/”Insert into page” phrase (used when inserting media into a post). Added in 4.4', 'brewpixel-bespoke' ),
					'uploaded_to_this_item' => _x( 'Uploaded to this testimonial', 'Overrides the “Uploaded to this post”/”Uploaded to this page” phrase (used when viewing media attached to a post). Added in 4.4', 'brewpixel-bespoke' ),
					'filter_items_list'     => _x( 'Filter testimonials list', 'Screen reader text for the filter links heading on the post type listing screen. Default “Filter posts list”/”Filter pages list”. Added in 4.4', 'brewpixel-bespoke' ),
					'items_list_navigation' => _x( 'Testimonials list navigation', 'Screen reader text for the pagination heading on the post type listing screen. Default “Posts list navigation”/”Pages list navigation”. Added in 4.4', 'brewpixel-bespoke' ),
					'items_list'            => _x( 'Testimonials list', 'Screen reader text for the items list heading on the post type listing screen. Default “Posts list”/”Pages list”. Added in 4.4', 'brewpixel-bespoke' ),
				],
				// Options.
				[
					'label'             => __( 'Testimonials', 'brewpixel-bespoke' ),
					'description'       => __( 'Description.', 'brewpixel-bespoke' ),
					'hierarchical'      => false,
					'public'            => true,
					'show_ui'           => true,
					'supports'          => [
						'title',
						'thumbnail'
					],
					'has_archive'       => true,
					'query_var'         => true,
					'show_in_menu'      => true,
					'show_in_nav_menus' => false,
					'rewrite'           => [
						'slug'       => 'testimonials',
						'with_front' => false,
					],
					'menu_position'     => 8,
					'menu_icon'         => 'dashicons-heart',
				],
				// Messages.
				[
					// Unused. Messages start at index 1.
					0  => '',
					1  => __( 'Testimonial updated.',
						'brewpixel-bespoke' ),
					2  => __( 'Custom field updated.', 'brewpixel-bespoke' ),
					3  => __( 'Custom field deleted.', 'brewpixel-bespoke' ),
					4  => __( 'Testimonial updated.',
						'brewpixel-bespoke' ),
					/* translators: %s: date and time of the revision */
					5  => isset( $_GET['revision'] ) ? sprintf( __( 'Testimonial restored to revision from %s',
						'brewpixel-bespoke' ),
						wp_post_revision_title( (int) $_GET['revision'],
							false ) ) : false,
					6  => __( 'Testimonial published.', 'brewpixel-bespoke' ),
					7  => __( 'Testimonial saved.', 'brewpixel-bespoke' ),
					8  => __( 'Testimonial submitted.', 'brewpixel-bespoke' ),
					9  => sprintf( __( 'Testimonial scheduled for: <strong>%1$s</strong>.',
						'brewpixel-bespoke' ),
						// translators: Publish box date format, see http://php.net/date
						date_i18n( __( 'M j, Y @ H:i' ),
							strtotime( $postdate ) )
					),
					10 => __( 'Testimonial draft updated.',
						'brewpixel-bespoke' ),
				]
			);

			$bp_testimonials_admin_metabox = new \BrewPixel\BrewPress\MetaBox
			\Metabox(
				'bp-testimonials',
				'Meta',
				'side',
				'high',
				array(
					'Feature' => 'checkbox',
				)
			);

			$bp_testimonials_admin_metabox = new \BrewPixel\BrewPress\MetaBox
			\Metabox(
				'bp-testimonials',
				'Client Review',
				'normal',
				'high',
				array(
					'Name of Client'                  => 'text',
					'Job title'         => array(
						'field_type' => 'text',
						'placeholder' => __( 'Events coordinator' ),
						'helpertext' => __( 'Keep this short if possible' ),
					),
					'First Name(s)'         => array(
						'field_type' => 'text',
						'placeholder' => __( 'Jane' ),
						'helpertext' => __( '' ),
					),
					'Last Name'         => array(
						'field_type' => 'text',
						'placeholder' => __( 'Smith' ),
						'helpertext' => __( '' ),
						'allowhtml'   => true,
					),
					'Company or Organisation'         => array(
						'field_type' => 'text',
						'placeholder' => __( 'Acme Inc.' ),
						'helpertext' => __( 'Company or Organisation' ),
					),
					'Rating' => array(
						'field_type' => 'select',
						array( '--Select Rating--', 0, .5, 1, 1.5, 2, 2.5, 3, 3.5, 4, 4.5, 5, 'Not rated', )
					),
					'Full review or testimonial'      => 'textarea',
					'Review'                          => 'textarea',
					'Short excerpt or teaser quote'   => 'textarea',
					'Date'          => 'date',
					'Month'                           => array(
						'field_type' => 'select',
						array(
							'--Select Month--',
							'January',
							'February',
							'March',
							'April',
							'May',
							'June',
							'July',
							'August',
							'September',
							'October',
							'November',
							'December'
						)
					),
					'Year'                            => array(
						'field_type' => 'select',
						array(
							'--Select Year--',
							'2013',
							'2014',
							'2015',
							'2016',
							'2017',
							'2018',
							'2019',
							'2020',
							'2021',
							'2022',
							'2023',
							'2024',
							'2025'
						)
					),
					'Additional Notes(Not Published)' => 'textarea'
				)
			);
		}
	}

}
