<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://brewpixel.com
 * @since      1.0.0
 *
 * @package    BrewPixel_Reviews
 * @subpackage BrewPixel_Reviews/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    BrewPixel_Reviews
 * @subpackage BrewPixel_Reviews/public
 * @author     Martin Goldie <martin@brewpixel.com>
 */
class BrewPixel_Reviews_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $brewpixel_reviews    The ID of this plugin.
	 */
	private $brewpixel_reviews;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $brewpixel_reviews       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $brewpixel_reviews, $version ) {

		$this->brewpixel_reviews = $brewpixel_reviews;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in BrewPixel_Reviews_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The BrewPixel_Reviews_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->brewpixel_reviews, plugin_dir_url( __FILE__ ) . 'css/brewpixel-reviews-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in BrewPixel_Reviews_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The BrewPixel_Reviews_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->brewpixel_reviews, plugin_dir_url( __FILE__ ) . 'js/brewpixel-reviews-public.js', array( 'jquery' ), $this->version, false );

	}

	public function display_archive_template( $templates ) {
		$templates[] = untrailingslashit( plugin_dir_path( __FILE__ ) ) . '/public/templates/archive-bp-testimonials.php';
	}

	public function display_single_template( $templates ) {
		$templates[] = untrailingslashit( plugin_dir_path( __FILE__ ) ) . '/public/templates/single-bp-testimonials.php';
	}

	public function override_templates( $template ) {

		$file = false;

		if( is_singular( 'bp-testimonials' ) ) {
			$file = 'single-bp-testimonials.php';
		}

		if( is_post_type_archive( 'bp-testimonials' ) ) {
			$file = 'archive-bp-testimonials.php';
		}

		/*
		if( is_page( $page_id_from_our_settings ) ) {
			$file = 'page-my-page.php';
		}
		*/

		// There is a file, create a new template path
		if( $file ) {
			// Check in Theme for folder my-plugin/templates/ and the file inside
			$template = locate_template( array( 'brewpixel-reviews/templates/' . $file ) );

			// If there is no template in the theme
			if( ! $template ) {
				// Get from Plugin's folder 'templates'
				$template = untrailingslashit( plugin_dir_path( __FILE__ ) ) . '/templates/' . $file;
			}
		}

		return $template;
	}
}
